import { useState } from "preact/hooks";
import { HexColorPicker } from "react-colorful";
import { Modal } from "../../Modal";

export const Color = ({ color: colorProp, onChange }) => {
    const [modalOpen, setModalOpen] = useState(false);
    const [color, setColor] = useState(colorProp);

    return (
        <>
            {modalOpen && (
                <ColorModal
                    color={color}
                    setModalOpen={setModalOpen}
                    onSave={setColor}
                ></ColorModal>
            )}
            <button
                class="change-color button is-rounded is-small"
                onClick={() => {
                    setModalOpen(true);
                }}
            >
                <span class="is-sr-only">Choose embed color</span>
                <i class="fas fa-eye-dropper"></i>
            </button>
        </>
    );
};

const ColorModal = ({ setModalOpen, color: colorProp, onSave }) => {
    const [color, setColor] = useState(colorProp);

    return (
        <Modal setModalOpen={setModalOpen} title={"Select Color"} onSubmit={onSave}>
            <div class="colorpicker-container">
                <HexColorPicker color={color} onChange={setColor}></HexColorPicker>
            </div>
            <br></br>
            <input
                class="input"
                id="colorInput"
                value={color}
                onChange={(ev) => {
                    setColor(ev.currentTarget.value);
                }}
            ></input>
        </Modal>
    );
};
